Struct Separated
pub struct Separated<'qb, 'args, DB, Sep>where
'args: 'qb,
DB: Database,{ /* private fields */ }Expand description
A wrapper around QueryBuilder for creating comma(or other token)-separated lists.
See QueryBuilder::separated() for details.
Implementations
impl<'qb, 'args, DB, Sep> Separated<'qb, 'args, DB, Sep>
impl<'qb, 'args, DB, Sep> Separated<'qb, 'args, DB, Sep>
pub fn push(&mut self, sql: impl Display) -> &mut Separated<'qb, 'args, DB, Sep>
pub fn push(&mut self, sql: impl Display) -> &mut Separated<'qb, 'args, DB, Sep>
Push the separator if applicable, and then the given SQL fragment.
See QueryBuilder::push() for details.
pub fn push_unseparated(
&mut self,
sql: impl Display,
) -> &mut Separated<'qb, 'args, DB, Sep>
pub fn push_unseparated( &mut self, sql: impl Display, ) -> &mut Separated<'qb, 'args, DB, Sep>
Push a SQL fragment without a separator.
Simply calls QueryBuilder::push() directly.
pub fn push_bind<T>(&mut self, value: T) -> &mut Separated<'qb, 'args, DB, Sep>
pub fn push_bind<T>(&mut self, value: T) -> &mut Separated<'qb, 'args, DB, Sep>
Push the separator if applicable, then append a bind argument.
See QueryBuilder::push_bind() for details.
pub fn push_bind_unseparated<T>(
&mut self,
value: T,
) -> &mut Separated<'qb, 'args, DB, Sep>
pub fn push_bind_unseparated<T>( &mut self, value: T, ) -> &mut Separated<'qb, 'args, DB, Sep>
Push a bind argument placeholder (? or $N for Postgres) and bind a value to it
without a separator.
Simply calls QueryBuilder::push_bind() directly.